import { Parameter, Connection } from './index.js';
import oracledb from 'oracledb';
class Oracle {
    constructor() {
        process.env.ORA_SDTZ = 'UTC';
        oracledb.autoCommit = true;
    }
    async connect(params) {
        return Connection.connect(params);
    }
    async beginTransaction(connectionData) {
        const conn = await Connection.connect(connectionData);
        return conn;
    }
    async fetch(conn, sql, params, executionParams) {
        try {
            const paramsToBind = params || {};
            const execParams = executionParams || {};
            const defaultFetchParams = {
                outFormat: oracledb.OUT_FORMAT_OBJECT,
            };
            const fetchParams = {
                ...defaultFetchParams,
                ...execParams,
            };
            return await conn.execute(sql, paramsToBind, fetchParams);
        }
        catch (error) {
            console.log(error.message);
            return Promise.reject(new Error(error.message));
        }
    }
    async execute(conn, sql, params, executionParams, outParams) {
        const paramsToBind = params || {};
        const execParameters = executionParams || {};
        const outParameters = outParams || [];
        const defaultExecParams = {
            outFormat: oracledb.OUT_FORMAT_OBJECT,
            autoCommit: true,
        };
        const execParams = {
            ...defaultExecParams,
            ...execParameters,
        };
        try {
            const { sql: returningSql, bind: bindOutParams } = Parameter.prepareOutputParams(outParameters);
            const bindParams = { ...paramsToBind, ...bindOutParams };
            const result = await conn.execute(`${sql} ${returningSql}`, bindParams, execParams);
            return result;
        }
        catch (error) {
            throw error;
        }
    }
}
const instance = new Oracle();
export { instance as Oracle };
export default instance;
