import oracledb from 'oracledb';
const paramTypes = {
    number: oracledb.NUMBER,
    string: oracledb.STRING,
    cursor: oracledb.CURSOR,
};
const directions = {
    in: oracledb.BIND_IN,
    out: oracledb.BIND_OUT,
    inout: oracledb.BIND_INOUT,
};
class Parameter {
    static getParamType(type) {
        return paramTypes[type];
    }
    static handleDirectionType(direction) {
        return direction ? directions[direction] : directions.in;
    }
    static prepareOutputParams(outParams) {
        if (!outParams.length) {
            return { sql: '', bind: {} };
        }
        const sqlParams = outParams.map((p) => p.name).join(', ');
        const sqlParamsInto = outParams.map((p) => `:${p.name}`).join(', ');
        const returningSql = `RETURNING ${sqlParams} INTO ${sqlParamsInto}`;
        const bind = {};
        outParams.forEach((param) => {
            bind[param.name] = { type: Parameter.getParamType(param.type), dir: oracledb.BIND_OUT };
        });
        return { sql: returningSql, bind };
    }
}
export { Parameter };
export default Parameter;
