import ms from 'ms';
import { AssistantPath, File, Hash } from '../../util/index.js';
import { InstalledProduct } from '../template/index.js';
const { REPORT_CACHE_TIME } = process.env;
const defaultCacheTime = REPORT_CACHE_TIME && !REPORT_CACHE_TIME.includes('<>') ? ms(REPORT_CACHE_TIME) : ms('1h');
class ReportTools {
    getControllerByReportId(reportId) {
        const controllers = {
            INSTALLED_PRODUCTS_ASSISTANT: InstalledProduct,
        };
        return controllers[reportId];
    }
    generateReportHashName(reportId, data, format) {
        const controller = this.getControllerByReportId(reportId);
        if (!controller) {
            throw new Error('INVALID_REPORT_ID');
        }
        const { fileName } = controller;
        const hash = Hash.generate(data);
        return `${fileName}.${hash}.${format.toLowerCase()}`;
    }
    async hasAvailableReportInCache(fileName, cacheTime = defaultCacheTime) {
        try {
            if (!fileName) {
                throw new Error('Empty report name');
            }
            const reportPath = AssistantPath.getReportPath();
            if (!cacheTime)
                return false;
            const fileStats = await new File(fileName, reportPath).stats();
            if (fileStats && fileStats.isFile()) {
                const createdAt = fileStats.mtime.getTime();
                if (createdAt > (Date.now() - cacheTime)) {
                    return true;
                }
            }
        }
        catch (err) {
            if (err.message.toLowerCase().includes('no such file or directory')) {
                return false;
            }
            throw err;
        }
        return false;
    }
}
const instance = new ReportTools();
export { instance as ReportTools };
export default instance;
