import { Request } from '../util/index.js';
import { Notification } from '../service/index.js';
class NotificationRoutes {
    register(app) {
        app.get('/notification/:userId', async (req, res) => {
            try {
                const { userId } = Request.getAllParams(req);
                const response = await Notification.findByUser(userId);
                res.status(200).send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.put('/notification/already-read', async (req, res) => {
            try {
                const { id, isAlreadyRead } = Request.getAllParams(req);
                const response = await Notification.updateAlreadyRead(id, isAlreadyRead);
                res.status(200).send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.put('/notification/already-read-all', async (req, res) => {
            try {
                const { userId } = Request.getAllParams(req);
                const response = await Notification.updateAlreadyReadAll({ userId });
                res.status(200).send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.delete('/notification', async (req, res) => {
            try {
                const { userId } = Request.getAllParams(req);
                const response = await Notification.removeNotificationsByUser({ userId });
                res.status(200).send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
    }
}
const instance = new NotificationRoutes();
export { instance as NotificationRoutes };
export default instance;
