import multer from 'multer';
import { UpdaterVersion } from '../service/index.js';
import { AssistantPath, Request } from '../util/index.js';
const storage = multer.diskStorage({
    destination: (req, file, cb) => {
        cb(null, AssistantPath.getUpdaterVersionPath());
    },
    filename: (req, file, cb) => {
        const { version } = Request.getAllParams(req);
        cb(null, `${version}.tar.gz`);
    },
});
const upload = multer({ storage });
class UpdaterVersionRoutes {
    register(app) {
        app.post('/updater-version/:version?', upload.single('file'), async (req, res) => {
            try {
                const response = await UpdaterVersion.create(Request.getAllParams(req));
                res.status(201).send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.get('/updater-version', async (req, res) => {
            try {
                const response = await UpdaterVersion.list();
                res.send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.put('/updater-version/:version?', async (req, res) => {
            try {
                const response = await UpdaterVersion.modify(Request.getAllParams(req));
                res.send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.delete('/updater-version/:version?', async (req, res) => {
            try {
                const response = await UpdaterVersion.remove(Request.getAllParams(req));
                res.send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
    }
}
const instance = new UpdaterVersionRoutes();
export { instance as UpdaterVersionRoutes };
export default instance;
